![banner](https://raw.githubusercontent.com/VFLins/cashd/main/src/cashd/assets/gh_banner-cashd.png)

<p align="center">
  <a href="https://github.com/VFLins/cashd/wiki/Instalando">
    <img alt="Como instalar" src="https://img.shields.io/badge/como_instalar-478eff?style=for-the-badge"></a>
  <a href="https://github.com/VFLins/cashd/wiki/Tutoriais">
    <img alt="Tutoriais" src="https://img.shields.io/badge/tutoriais-478eff?style=for-the-badge"></a>
  <a href="https://github.com/VFLins/cashd/wiki/Problemas-conhecidos">
    <img alt="Erros conhecidos" src="https://img.shields.io/badge/problemas_conhecidos-478eff?style=for-the-badge"></a>
</p>

Regsitre o seu *cashflow* rapidamente, ou faça controle de fiado. Seus dados serão só seus!

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
